# docx-form

## Description

This package allows you to easily modify the values of content controls on forms in Microsoft Word with python scripts. This project currently supports reading and editting of the combo box, check box, plain text, datepicker, and dropdown content controls through the package's functions. The file being modified can be overwritten with the new values or saved to a new file.

## Setup For Use

#### Requirements:

- Pip
- Python version 3.10.6 or higher

Simply run "pip install docx-form" to install docx-form and its required dependencies. After pip is installed, all that is left to do is import the project with "from docx_form import DocxForm".
[Link to Pip project](https://pypi.org/project/docx-form/)

## Setup For Contribution

#### Requirements:

- Pip
- Python version 3.10.6 or higher
- Poetry 1.2.0

Clone the repository, for those who aren't familiar [https://docs.github.com/en/repositories/creating-and-managing-repositories/cloning-a-repository](https://docs.github.com/en/repositories/creating-and-managing-repositories/cloning-a-repository).

## Poetry Installation

First install Python using powershell.
Link to install: [https://python-poetry.org/docs/](https://python-poetry.org/docs/)
Once installed, grab poetry application from the poetry script folder and manually add it to your Python scripts folder. Then in the project environment set the interpreter path to the pypoetry virtual environment. Run Poetry install to install all poetry's dependecies. For visual studio code, cmd + p is the command to select intepreter.

Then fetch development and pull in changes and make a new branch off development to start contributing.
